## Raw

## Type: Raw

➔

## Colour_correction

## Type: Colour

    {
                    "name": "colour_correction",
                    "step_name": "colour",
                    "mode": "grayscale",
                    "test": false
                    }

    {
                "name": "raw",
                "step_name": "raw",
                "sample_data": "benthic_csv",
                "input_path": "/home/tobfer/.paidiverpy_cache/benthic_csv/images",
                "metadata_path": "/home/tobfer/.paidiverpy_cache/benthic_csv/metadata/metadata_benthic_csv.csv",
                "metadata_type": "CSV_FILE",
                "image_open_args": "PNG",
                "append_data_to_metadata": "/home/tobfer/.paidiverpy_cache/benthic_csv/metadata/appended_metadata_benthic_csv.csv",
                "output_path": "output",
                "n_jobs": 1,
                "rename": "datetime",
                "sampling": [
                  {
                      "name": "sampling",
                      "step_name": "sampling",
                      "mode": "percent",
                      "test": false,
                      "params": {
                          "value": 0.1
                      }
                  }
                ],
                "convert": [
                  {
                      "name": "convert",
                      "step_name": "convert",
                      "mode": "bits",
                      "test": false,
                      "params": {
                          "output_bits": 8
                      }
                  }
                ]
                }